@@ -27,4 +27,14 @@ class Items(Client):
                                             "method": "DELETE"
                                         },
                                         mimetype="application/x-www-form-urlencoded",
+                                        )
+
+    def get_price_book_rate(self, query: dict = None):
+        return self.authenticated_fetch(path=f"pricebookrate/",
+                                        req={
+                                            "method": "POST",
+                                            "query": query or {}
+                                        },
+                                        mimetype="application/x-www-form-urlencoded",
+                                        encode_json_string=True,
                                         )
\ No newline at end of file
